InboxApiClient class abstract

Implementers

Constructors

InboxApiClient()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

inboxDeleteMessage(String messageId) Future<void>
inboxFetchMessages({int limit = 20, String? cursor}) Future<Map<String, dynamic>>
inboxFetchUnreadCount() Future<int>
inboxMarkAllAsRead() Future<void>
inboxMarkAsRead(String messageId) Future<void>
inboxTrackAction(String messageId) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited