transparentBody property
When true, the body background color is forced to transparent. Used when the parent widget renders the background image separately.
Implementation
final bool transparentBody;
When true, the body background color is forced to transparent. Used when the parent widget renders the background image separately.
final bool transparentBody;